@@ -1,10 +1,10 @@
-from graph import (
+from .graph import (
         run_pipegraph,
         new_pipegraph,
         forget_job_status,
         destroy_global_pipegraph
         )
-from ppg_exceptions import (
+from .ppg_exceptions import (
         RuntimeError,
         RuntimeException,
         CycleError,
@@ -12,10 +12,14 @@ from ppg_exceptions import (
         PyPipeGraphError,
         JobDiedException
         )
-import twisted_fork
-import util
+try:
+    from . import twisted_fork
+    twisted_available = True
+except ImportError:
+    twisted_available = False
+from . import util
 
-from job import (
+from .job import (
     Job, JobList,
     FileGeneratingJob, MultiFileGeneratingJob,
     DataLoadingJob, AttributeLoadingJob,
@@ -48,7 +52,7 @@ all = [
         JobGeneratingJob, DependencyInjectionJob,
         FinalJob,
 
-        util, twisted_fork
-
-
+        util
         ]
+if twisted_available:
+    all.append(twisted_fork)
